@@ -3,7 +3,7 @@
 #
 # kluster/kox point process models
 #
-# $Revision: 1.227 $ $Date: 2023/01/25 05:16:09 $
+# $Revision: 1.230 $ $Date: 2023/03/26 10:08:44 $
 #
 
 kppm <- function(X, ...) {
@@ -1145,8 +1145,8 @@ kppmPalmLik <- function(X, Xname, po, clusters, control=list(), stabilize=TRUE,
     # stationary unmarked Poisson process
     lambda <- intensity(X)
     lambdaJ <- rep(lambda, length(J))
-    # compute cdf of distance between a uniform random point in W
-    # and a randomly-selected point in X 
+    # compute cdf of distance between a randomly-selected point in X 
+    # and a uniform random point in W
     g <- distcdf(X, M, delta=rmax/4096)
     # scaling constant is (integral of intensity) * (number of points)
     gscale <- npoints(X)^2
@@ -1155,7 +1155,7 @@ kppmPalmLik <- function(X, Xname, po, clusters, control=list(), stabilize=TRUE,
     lambdaX <- fitted(po, dataonly=TRUE)
     lambda <- lambdaM <- predict(po, locations=M)
     lambdaJ <- lambdaX[J] 
-    # compute cdf of distance between a uniform random point in X 
+    # compute cdf of distance between a randomly-selected point in X 
     # and a random point in W with density proportional to intensity function
     g <- distcdf(X, M, dV=lambdaM, delta=rmax/4096)
     # scaling constant is (integral of intensity) * (number of points)
@@ -2223,7 +2223,7 @@ labels.kppm <- labels.dppm <- function(object, ...) {
   labels(object$po, ...)
 }
 
-update.kppm <- function(object, ..., evaluate=TRUE, envir=environment(terms(object))) {
+update.kppm <- update.dppm <- function(object, ..., evaluate=TRUE, envir=environment(terms(object))) {
   argh <- list(...)
   nama <- names(argh)
   callframe <- object$callframe
@@ -2351,14 +2351,19 @@ unitname.kppm <- unitname.dppm <- function(x) {
 }
 
 as.fv.kppm <- as.fv.dppm <- function(x) {
-  if(x$Fit$method == "mincon")
+  if(x$Fit$method == "mincon") 
     return(as.fv(x$Fit$mcfit))
-  gobs <- if(is.stationary(x)) pcf(x$X, correction="good") else pcfinhom(x$X, lambda=x, correction="good", update=FALSE)
+  gobs <- if(is.stationary(x)) {
+            pcf(x$X, correction="good")
+          } else {
+            pcfinhom(x$X, lambda=x, correction="good", update=FALSE)
+          }
+  gname <- attr(gobs, "fname")
   gfit <- (pcfmodel(x))(gobs$r)
   g <- bind.fv(gobs,
-               data.frame(fit=gfit), 
-               "%s[fit](r)",
-               "predicted %s for fitted model")
+               data.frame(fit=gfit),
+               labl = makefvlabel(fname=gname, sub="fit"),
+               desc = "predicted %s for fitted model")
   return(g)
 }
 
